<template>
  <el-card class="card-container">
    <div class="flex-container mb-4">
      <el-tabs v-model="currentTab" @tab-click="handleClick" v-show="isShow">
        <el-tab-pane
          v-for="item in TABS_DATA"
          :key="item.value"
          :label="item.label"
          :name="item.value"
        >
          <template slot-scope="item">
            <div class="tab-label">{{ item.label }}</div>
          </template>
        </el-tab-pane>
      </el-tabs>
    </div>
    <component
      :is="componentName"
      ref="childRef"
      :disabled="disabled"
      @toNext="changeTable"
      @updateIsShow="updateIsShow"
      :isShow="isShow"
      class="full-width custom-height"
    />
    <div v-if="!disabled" class="button-container">
      <el-button
        v-if="componentName.name == 'BasicInfo'"
        class="save-button"
        type="primary"
        @click="submit(0)"
        >草稿</el-button
      >
      <el-button class="save-button" type="primary" @click="submit(1)"
        >保存</el-button
      >
      <el-button class="reset-button" @click="reset">重置</el-button>
      <!-- <el-button v-else class="cancel-button" @click="cancel">取消</el-button> -->
    </div>
  </el-card>
</template>

<script>
import BasicInfo from "@/views/projectEngineering/projectLibrary/component/BasicInfo";
import InvestInfo from "@/views/projectEngineering/projectLibrary/component/InvestInfo";
import InvestmentFunds from "@/views/projectEngineering/projectLibrary/component/investmentFunds";
import LegalPerson from "@/views/projectEngineering/projectLibrary/component/legalPerson";
import PolicyInfo from "@/views/projectEngineering/projectLibrary/component/PolicyInfo";
import DocumentsInfo from "@/views/projectEngineering/projectLibrary/component/DocumentsInfo";

export default {
  name: "ProjectDetails",
  data() {
    return {
      isShow: false,
      currentTab: "项目管理基础信息",
      disabled: false,
      projectForm: {},
      componentName: BasicInfo,
      TABS_DATA: [
        {
          label: "项目管理基础信息",
          value: "项目管理基础信息",
          componentName: BasicInfo,
        },
        {
          label: "投资管理基础信息",
          value: "投资管理基础信息",
          componentName: InvestInfo,
        },
        {
          label: "项目投资及资金来源",
          value: "项目投资及资金来源",
          componentName: InvestmentFunds,
        },
        {
          label: "项目(法人)单位登记信息",
          value: "项目(法人)单位登记信息",
          componentName: LegalPerson,
        },
        {
          label: "投资项目产业政策符合情况",
          value: "投资项目产业政策符合情况",
          componentName: PolicyInfo,
        },
        {
          label: "相关文书",
          value: "相关文书",
          componentName: DocumentsInfo,
        },
      ],
      childRef: null,
    };
  },
  methods: {
    updateIsShow(newValue) {
      this.isShow = newValue;
    },
    handleClick(tabTarget) {
      this.componentName = this.TABS_DATA[tabTarget.index].componentName;
      
    },
    changeTable(index) {
      this.componentName = this.TABS_DATA[index].componentName;
      this.currentTab = this.TABS_DATA[index].value;
    },
    submit(usedStatus) {
      this.$refs.childRef.submit(usedStatus);
    },
    reset() {
      this.$refs.childRef.reset();
    },
  },
  mounted() {
    if (this.$route.query.disabled) {
      this.disabled = true;
    }
  },
};
</script>

<style scoped>
::v-deep .el-tabs__nav-wrap::after {
  background-color: rgba(0, 0, 0, 0) !important;
}
.flex-container {
  display: flex;
  justify-content: space-between;
  margin-bottom: 16px;
}

.tab-label {
  font-size: 14px;
}

.full-width {
  width: 100%;
}

.custom-height {
  height: calc(100% - 55px);
}

.button-container {
  margin-top: 3%;
  margin-left: 3%;
  display: flex;
}

.save-button,
.reset-button {
  width: 72px;
}
</style>
